@@ -24,7 +24,7 @@
 #include "Screen.h"
 
 // Qt
-#include <QtCore/QTextStream>
+#include <QTextStream>
 
 // Konsole
 #include "konsole_wcwidth.h"
@@ -34,10 +34,6 @@
 
 using namespace Konsole;
 
-//FIXME: this is emulation specific. Use false for xterm, true for ANSI.
-//FIXME: see if we can get this from terminfo.
-const bool BS_CLEARS = false;
-
 //Macro to convert x,y position on screen to position within an image.
 //
 //Originally the image was stored as one large contiguous block of
@@ -241,7 +237,7 @@ void Screen::insertLines(int n)
 
 void Screen::setMode(int m)
 {
-    _currentModes[m] = true;
+    _currentModes[m] = 1;
     switch (m) {
     case MODE_Origin :
         _cuX = 0;
@@ -252,7 +248,7 @@ void Screen::setMode(int m)
 
 void Screen::resetMode(int m)
 {
-    _currentModes[m] = false;
+    _currentModes[m] = 0;
     switch (m) {
     case MODE_Origin :
         _cuX = 0;
@@ -273,7 +269,7 @@ void Screen::restoreMode(int m)
 
 bool Screen::getMode(int m) const
 {
-    return _currentModes[m];
+    return _currentModes[m] != 0;
 }
 
 void Screen::saveCursor()
@@ -310,7 +306,7 @@ void Screen::resizeImage(int new_lines, int new_columns)
 
     // create new screen _lines and copy from old to new
 
-    ImageLine* newScreenLines = new ImageLine[new_lines + 1];
+    auto newScreenLines = new ImageLine[new_lines + 1];
     for (int i = 0; i < qMin(_lines, new_lines + 1) ; i++)
         newScreenLines[i] = _screenLines[i];
     for (int i = _lines; (i > 0) && (i < new_lines + 1); i++)
@@ -377,7 +373,7 @@ void Screen::reverseRendition(Character& p) const
 void Screen::updateEffectiveRendition()
 {
     _effectiveRendition = _currentRendition;
-    if (_currentRendition & RE_REVERSE) {
+    if ((_currentRendition & RE_REVERSE) != 0) {
         _effectiveForeground = _currentBackground;
         _effectiveBackground = _currentForeground;
     } else {
@@ -385,11 +381,11 @@ void Screen::updateEffectiveRendition()
         _effectiveBackground = _currentBackground;
     }
 
-    if (_currentRendition & RE_BOLD) {
-        if (!(_currentRendition & RE_FAINT))
+    if ((_currentRendition & RE_BOLD) != 0) {
+        if ((_currentRendition & RE_FAINT) == 0)
             _effectiveForeground.setIntensive();
     } else {
-        if (_currentRendition & RE_FAINT)
+        if ((_currentRendition & RE_FAINT) != 0)
             _effectiveForeground.setFaint();
     }
 }
@@ -511,8 +507,8 @@ void Screen::reset()
     scrollUp(0, _cuY);
     _cuY = 0;
 
-    _currentModes[MODE_Origin] = false;
-    _savedModes[MODE_Origin] = false;
+    _currentModes[MODE_Origin] = 0;
+    _savedModes[MODE_Origin] = 0;
 
     setMode(MODE_Wrap);
     saveMode(MODE_Wrap);      // wrap at end of margin
@@ -534,12 +530,6 @@ void Screen::reset()
     saveCursor();
 }
 
-void Screen::clear()
-{
-    clearEntireScreen();
-    home();
-}
-
 void Screen::backspace()
 {
     _cuX = qMin(_columns - 1, _cuX); // nowrap!
@@ -547,11 +537,6 @@ void Screen::backspace()
 
     if (_screenLines[_cuY].size() < _cuX + 1)
         _screenLines[_cuY].resize(_cuX + 1);
-
-    if (BS_CLEARS) {
-        _screenLines[_cuY][_cuX].character = ' ';
-        _screenLines[_cuY][_cuX].rendition = _screenLines[_cuY][_cuX].rendition & ~RE_EXTENDED_CHAR;
-    }
 }
 
 void Screen::tab(int n)
@@ -668,10 +653,10 @@ void Screen::displayCharacter(unsigned short c)
             ushort extendedCharLength;
             const ushort* oldChars = ExtendedCharTable::instance.lookupExtendedChar(currentChar.character, extendedCharLength);
             Q_ASSERT(oldChars);
-            if (oldChars && extendedCharLength < 3) {
+            if (((oldChars) != nullptr) && extendedCharLength < 3) {
                 Q_ASSERT(extendedCharLength > 1);
                 Q_ASSERT(extendedCharLength < 65535);
-                ushort* chars = new ushort[extendedCharLength + 1];
+                auto chars = new ushort[extendedCharLength + 1];
                 memcpy(chars, oldChars, sizeof(ushort) * extendedCharLength);
                 chars[extendedCharLength] = c;
                 currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars, extendedCharLength + 1);
@@ -712,7 +697,7 @@ void Screen::displayCharacter(unsigned short c)
 
     int i = 0;
     const int newCursorX = _cuX + w--;
-    while (w) {
+    while (w != 0) {
         i++;
 
         if (_screenLines[_cuY].size() < _cuX + i + 1)
@@ -761,13 +746,18 @@ QRect Screen::lastScrolledRegion() const
 
 void Screen::scrollUp(int from, int n)
 {
-    if (n <= 0 || from + n > _bottomMargin) return;
+    if (n <= 0)
+        return;
+    if (from > _bottomMargin)
+        return;
+    if (from + n > _bottomMargin)
+        n = _bottomMargin + 1 - from;
 
     _scrolledLines -= n;
     _lastScrolledRegion = QRect(0, _topMargin, _columns - 1, (_bottomMargin - _topMargin));
 
     //FIXME: make sure `topMargin', `bottomMargin', `from', `n' is in bounds.
-    moveImage(loc(0, from), loc(0, from + n), loc(_columns - 1, _bottomMargin));
+    moveImage(loc(0, from), loc(0, from + n), loc(_columns, _bottomMargin));
     clearImage(loc(0, _bottomMargin - n + 1), loc(_columns - 1, _bottomMargin), ' ');
 }
 
@@ -812,12 +802,6 @@ void Screen::setCursorY(int y)
     _cuY = qMax(0, qMin(_lines  - 1, y + (getMode(MODE_Origin) ? _topMargin : 0)));
 }
 
-void Screen::home()
-{
-    _cuX = 0;
-    _cuY = 0;
-}
-
 void Screen::toStartOfLine()
 {
     _cuX = 0;
@@ -1245,6 +1229,8 @@ int Screen::copyLineToStream(int line ,
 
         int screenLine = line - _history->getLines();
 
+        // FIXME: This can be triggered when clearing history
+        //  while having the searchbar open and selecting next/prev
         Q_ASSERT(screenLine <= _screenLinesSize);
 
         screenLine = qMin(screenLine, _screenLinesSize);
@@ -1253,7 +1239,7 @@ int Screen::copyLineToStream(int line ,
         int length = _screenLines[screenLine].count();
 
         // Don't remove end spaces in lines that wrap
-        if (trimTrailingSpaces && !(_lineProperties[screenLine] & LINE_WRAPPED))
+        if (trimTrailingSpaces && ((_lineProperties[screenLine] & LINE_WRAPPED) == 0))
         {
             // ignore trailing white space at the end of the line
             for (int i = length-1; i >= 0; i--)
@@ -1278,7 +1264,7 @@ int Screen::copyLineToStream(int line ,
     }
 
     if (appendNewLine && (count + 1 < MAX_CHARS)) {
-        if (currentLineProperties & LINE_WRAPPED) {
+        if ((currentLineProperties & LINE_WRAPPED) != 0) {
             // do nothing extra when this line is wrapped.
         } else {
             // When users ask not to preserve the linebreaks, they usually mean:
@@ -1310,7 +1296,7 @@ void Screen::addHistLine()
         const int oldHistLines = _history->getLines();
 
         _history->addCellsVector(_screenLines[0]);
-        _history->addLine(_lineProperties[0] & LINE_WRAPPED);
+        _history->addLine((_lineProperties[0] & LINE_WRAPPED) != 0);
 
         const int newHistLines = _history->getLines();
 
